local mod = ...

--[[

	Adds dung produced by animals, a dung heap for collection and impacts to production.

]]--


-- Job -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "DUNGCOLLECTOR_JOB",
	JobName = "DUNGCOLLECTOR_JOB_NAME",
	JobDescription = "DUNGCOLLECTOR_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 30.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_COAL_BURNER_SHOVEL"
		},
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "DUNGCOLLECTOR_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "DUNGCOLLECTOR_JOB"
    }
})



-- Resource -------------------------------------------------------------------------------------

mod:registerAssetId("icons/Dung.png", "ICON_DUNG")

mod:register({
	DataType = "RESOURCE",
	Id = "DUNG_RESOURCE",
	ResourceName = "DUNG_RESOURCE_NAME",
	Icon = "ICON_DUNG",
	ResourceTypeList = { "RESOURCE" },
	IsTradable = false,
	ResourceLayoutType = "CRATES",
	-- VillagerBuyingPrice = { Resource = "GOLD", Quantity = 2 },
	DisplayInInventory = true
})



-- Assets
mod:registerAssetId("models/DungHeap.fbx/Prefab/DungHeapPart", "PREFAB_DUNGHEAP")



-- Building Asset Processor
mod:registerAssetProcessor("models/DungHeap.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Grounding
mod:registerPrefabComponent("models/DungHeap.fbx/Prefab/DungHeap", {DataType = "COMP_GROUNDED"})



-- Building Function: Dung heap  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "DUNGHEAP_FUNCTION",
    Name = "DUNGHEAP_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "DUNGCOLLECTOR_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {{ Resource = "DUNG_RESOURCE", Quantity = 100000 }},
    ResourceListNeeded = {{ Resource = "DUNG_RESOURCE", Quantity = 1 }},
    ResourceProduced = {{ Resource = "DUNG_RESOURCE", Quantity = 1 }}
})



-- Building -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING", 
	Id = "DUNGHEAP",
	Name = "DUNGHEAP_NAME",
	Description = "DUNGHEAP_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "DUNGHEAP_PART",
	IsEditable = true
})



-- Building Part: Dung heap -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "DUNGHEAP_PART",
	Name = "DUNGHEAP_PART_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_DUNGHEAP"
	},
	ConstructionVisual = "PREFAB_DUNGHEAP",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 1.85, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
			}
		}
	},
	AssetBuildingFunction = "DUNGHEAP_FUNCTION",
	-- Cost = {
	-- 	RessourcesNeeded = {
    --         { Resource = "WOOD", Quantity = 5 },
    --         { Resource = "TOOL", Quantity = 1 }
	-- 	}
	-- },
	DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "SUBSTRACT",
		Radius = 15.0,
		Value = 1.0
	} }
})


